lcvtoolbox.integrations.cvat.api.CvatTask
=========================================

.. currentmodule:: lcvtoolbox.integrations.cvat.api

.. autoclass:: CvatTask
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatTask.__init__
      ~CvatTask.create_annotated_images
      ~CvatTask.download_images
      ~CvatTask.get_image
      ~CvatTask.get_job_by_frame
      ~CvatTask.get_job_by_id
      ~CvatTask.get_job_statistics
      ~CvatTask.get_shapes_for_frame
      ~CvatTask.get_tags_for_frame
      ~CvatTask.list_jobs
      ~CvatTask.process
      ~CvatTask.process_job_by_job_with_images
      ~CvatTask.process_jobs
      ~CvatTask.process_jobs_with_callback
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatTask.annotated_images
      ~CvatTask.annotations
      ~CvatTask.assignee
      ~CvatTask.details
      ~CvatTask.frames
      ~CvatTask.frames_names
      ~CvatTask.frames_numbers
      ~CvatTask.job_count
      ~CvatTask.job_details
      ~CvatTask.job_ids
      ~CvatTask.jobs
      ~CvatTask.length
      ~CvatTask.metainformation
      ~CvatTask.name
      ~CvatTask.owner
      ~CvatTask.project_id
      ~CvatTask.status
   
   